animationAlignment property
Defines how the expanding content is aligned within its available space.
Implementation
final AlignmentGeometry animationAlignment;
Defines how the expanding content is aligned within its available space.
final AlignmentGeometry animationAlignment;